#' Pretty heatmaps
#' 
#' Implementation of heatmaps that offers more control
#' over dimensions and appearance.
#' 
#' @name pheatmap-package
#' 
#' @import grid
#' @import RColorBrewer
#' @import scales
#' @import gtable
#' @import stats
#' @import grDevices
#' @import graphics
#' 
#' @keywords internal 
"_PACKAGE"
